"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vue_1 = require("vue");
const seemly_1 = require("seemly");
const vooks_1 = require("vooks");
const _mixins_1 = require("../../_mixins");
const _utils_1 = require("../../_utils");
const index_cssr_1 = require("./styles/index.cssr");
const styles_1 = require("../styles");
const switchProps = Object.assign(Object.assign({}, _mixins_1.useTheme.props), { size: {
        type: String,
        default: 'medium'
    }, value: {
        type: Boolean,
        default: undefined
    }, defaultValue: {
        type: Boolean,
        default: false
    }, disabled: {
        type: Boolean,
        default: false
    }, round: {
        type: Boolean,
        default: true
    }, 
    // eslint-disable-next-line vue/prop-name-casing
    'onUpdate:value': [Function, Array], onUpdateValue: [Function, Array], onChange: {
        type: [Function, Array],
        validator: () => {
            if (process.env.NODE_ENV !== 'production') {
                _utils_1.warn('switch', '`on-change` is deprecated, please use `on-update:value` instead.');
            }
            return true;
        },
        default: undefined
    } });
exports.default = vue_1.defineComponent({
    name: 'Switch',
    props: switchProps,
    setup(props) {
        const { mergedClsPrefixRef } = _mixins_1.useConfig(props);
        const themeRef = _mixins_1.useTheme('Switch', 'Switch', index_cssr_1.default, styles_1.switchLight, props, mergedClsPrefixRef);
        const formItem = _mixins_1.useFormItem(props);
        const { mergedSizeRef } = formItem;
        const uncontrolledValueRef = vue_1.ref(props.defaultValue);
        const controlledValueRef = vue_1.toRef(props, 'value');
        const mergedValueRef = vooks_1.useMergedState(controlledValueRef, uncontrolledValueRef);
        function doUpdateValue(value) {
            const { 'onUpdate:value': _onUpdateValue, onChange, onUpdateValue } = props;
            const { nTriggerFormInput, nTriggerFormChange } = formItem;
            if (_onUpdateValue)
                _utils_1.call(_onUpdateValue, value);
            if (onUpdateValue)
                _utils_1.call(onUpdateValue, value);
            if (onChange)
                _utils_1.call(onChange, value);
            uncontrolledValueRef.value = value;
            nTriggerFormInput();
            nTriggerFormChange();
        }
        function doFocus() {
            const { nTriggerFormFocus } = formItem;
            nTriggerFormFocus();
        }
        function doBlur() {
            const { nTriggerFormBlur } = formItem;
            nTriggerFormBlur();
        }
        function handleClick() {
            if (!props.disabled) {
                doUpdateValue(!mergedValueRef.value);
            }
        }
        function handleFocus() {
            doFocus();
        }
        function handleBlur() {
            doBlur();
        }
        return {
            handleClick,
            handleBlur,
            handleFocus,
            mergedClsPrefix: mergedClsPrefixRef,
            mergedValue: mergedValueRef,
            cssVars: vue_1.computed(() => {
                const { value: size } = mergedSizeRef;
                const { self: { opacityDisabled, railColor, railColorActive, buttonBoxShadow, buttonColor, [_utils_1.createKey('buttonHeight', size)]: buttonHeight, [_utils_1.createKey('buttonWidth', size)]: buttonWidth, [_utils_1.createKey('buttonWidthPressed', size)]: buttonWidthPressed, [_utils_1.createKey('railHeight', size)]: railHeight, [_utils_1.createKey('railWidth', size)]: railWidth, [_utils_1.createKey('railBorderRadius', size)]: railBorderRadius, [_utils_1.createKey('buttonBorderRadius', size)]: buttonBorderRadius }, common: { cubicBezierEaseInOut } } = themeRef.value;
                const offset = seemly_1.pxfy((seemly_1.depx(railHeight) - seemly_1.depx(buttonHeight)) / 2);
                const height = seemly_1.pxfy(Math.max(seemly_1.depx(railHeight), seemly_1.depx(buttonHeight)));
                const width = seemly_1.depx(railHeight) > seemly_1.depx(buttonHeight)
                    ? railWidth
                    : seemly_1.pxfy(seemly_1.depx(railWidth) + seemly_1.depx(buttonHeight) - seemly_1.depx(railHeight));
                return {
                    '--bezier': cubicBezierEaseInOut,
                    '--button-border-radius': buttonBorderRadius,
                    '--button-box-shadow': buttonBoxShadow,
                    '--button-color': buttonColor,
                    '--button-width': buttonWidth,
                    '--button-width-pressed': buttonWidthPressed,
                    '--button-height': buttonHeight,
                    '--height': height,
                    '--offset': offset,
                    '--opacity-disabled': opacityDisabled,
                    '--rail-border-radius': railBorderRadius,
                    '--rail-color': railColor,
                    '--rail-color-active': railColorActive,
                    '--rail-height': railHeight,
                    '--rail-width': railWidth,
                    '--width': width
                };
            })
        };
    },
    render() {
        const { mergedClsPrefix } = this;
        return (vue_1.h("div", { class: [
                `${mergedClsPrefix}-switch`,
                {
                    [`${mergedClsPrefix}-switch--active`]: this.mergedValue,
                    [`${mergedClsPrefix}-switch--disabled`]: this.disabled,
                    [`${mergedClsPrefix}-switch--round`]: this.round
                }
            ], tabindex: !this.disabled ? 0 : undefined, style: this.cssVars, onClick: this.handleClick, onFocus: this.handleFocus, onBlur: this.handleBlur },
            vue_1.h("div", { class: `${mergedClsPrefix}-switch__rail` })));
    }
});
